"use strict";
const refs_1 = require('./refs');
const utils_1 = require('./utils');
class CCController {
    constructor(router = null, debugSettings) {
        this.router = router;
        this.debugSettings = debugSettings;
        if (!this.router)
            this.router = refs_1.Router();
        if (!debugSettings)
            debugSettings = { debug: false };
        this.setRoutes();
        this._setProxiedMethods();
    }
    setRoutes() { }
    setDefaultRoutes(...middlewares) {
        return this.router;
    }
    /**
     * Instead of returning the result you can use this method to pass the return result
     * @result {hashmap|}
     */
    send(req, res, data, senderFunction) {
        let sf = senderFunction;
        if (!sf) {
            sf = this.senderFunction.bind(this);
        }
        utils_1.send(req, res, data, sf);
    }
    senderFunction(res, err, data) {
        return utils_1.sendData(res, err, data);
    }
    error(req, res, data) {
        console.log('error happened, please fix me ');
        res.sendStatus(401);
    }
    proxied(method) {
        return (req, res, next) => {
            try {
                let result = method.apply(this, [req, res, next]);
                this.send(req, res, result);
            }
            catch (ex) {
                console.log(`Just Crashed with Error:${ex.message}`);
                if (ex.stack)
                    console.log(ex.stack);
                res.sendStatus(500);
            }
        };
    }
    _setProxiedMethods() {
        if (this['proxyHandlerDescriptors']) {
            let proxyHandlerDescriptors = this['proxyHandlerDescriptors'];
            proxyHandlerDescriptors.forEach(p => {
                this[p.methodName] = this.proxied(this[p.methodName]);
                this.router[p.verb].apply(this.router, [p.resource, ...p.handlers, this[p.methodName].bind(this)]);
            });
            this['proxyHandlerDescriptors'] = proxyHandlerDescriptors.slice(0, this.proxyHandlerDescriptors.length);
        }
    }
    ctrl(name) {
        return this.proxied(this[name]);
    }
}
exports.CCController = CCController;

//# sourceMappingURL=ccController.js.map
