import * as mongoose from 'mongoose';
export declare type ObjectId = mongoose.Schema.Types.ObjectId;
export declare type Clb<T> = (error: any, result: T) => any;
export declare type Id = ObjectId | string | number;
export declare class CCService<T extends mongoose.Document> {
    modelName: string;
    model: mongoose.Model<T>;
    constructor(modelName: any);
    /**
     * Retrieves all documents from the collection
     */
    getAll(callback?: Clb<T[]>): Promise<T[]>;
    /**
     * Retrieves a document by it's Id
     */
    byId(id: string | number | ObjectId, callback?: Clb<T>): Promise<T>;
    /**
     * Updates the document by the given id and returns it
     * @param {string | number | ObjectId} id the Id of the document in the db
     * @param  {any} update a hashmap of the fields to update and their new values as keys
     * @param {Clb<T>}  callback optional callback that can be used to retrieve the results
     * @returns {Primise<T>}
     */
    updateById(id: string | number | ObjectId, update: any, callback?: Clb<T>): Promise<T>;
    /**
     * Deletes a document by the given id and returns it
     */
    deleteById(id: string | number | ObjectId, callback?: Clb<T>): Promise<T>;
    /**
     * For a given object it tries to create T instance, saves it to the database and returns it
     * @argument document:any
     * @returns T
     */
    createAndSave(document: any, callback?: Clb<T>): Promise<T>;
    /**
     * From a given array of objects it tries to create T[] array and saves it to the database
     */
    createAndSaveMany(documents: any[], callback?: Clb<T[]>): Promise<T[]>;
    /**
     * Creates a new object of type T and returns it.
     * @param {any} document a hasmap with the fields we want to create the object from
     * @param  {Clb<T>} an optional callback function that can be used to get the newly created object
     */
    create(document?: any, callback?: Clb<T>): T;
    insert(document: T, callback?: Clb<T>): Promise<T>;
}
